import axios from 'axios';
import type { Form, Submission } from './types';

const API_BASE = 'http://localhost:8080'; // Backend URL

// Fetch all forms
export async function fetchForms(): Promise<Form[]> {
	const response = await axios.get(`${API_BASE}/forms`);
	return response.data;
}

// Create a new form
export async function createForm(form: Omit<Form, 'id' | 'created_at'>): Promise<string> {
	const response = await axios.post(`${API_BASE}/forms`, form);
	return response.data; // Returns the created form's ID
}

// Fetch form submissions
export async function fetchSubmissions(formId: string): Promise<Submission[]> {
	const response = await axios.get(`${API_BASE}/forms/${formId}/submissions`);
	return response.data;
}

// Submit a form
export async function submitForm(formId: string, data: Record<string, unknown>): Promise<string> {
	const response = await axios.post(`${API_BASE}/forms/${formId}/submissions`, data);
	return response.data; // Returns the submission ID
}
